@@ -9,7 +9,6 @@ from .expenses import Expenses
 from .tax_groups import TaxGroups
 from .reimbursements import Reimbursements
 from .settlements import Settlements
-from .invitations import Invitations
 from .projects import Projects
 from ..version import version
 
@@ -19,7 +18,6 @@ categories = Categories(version, role)
 cost_centers = CostCenters(version, role)
 employees = Employees(version, role)
 projects = Projects(version, role)
-invitations = Invitations(version, role)
 expenses = Expenses(version, role)
 tax_groups = TaxGroups(version, role)
 reimbursements = Reimbursements(version, role)
